import  setuptools


setuptools.setup(
    name="combined_clustering_algorithm",
    version="1.0.0",
    author="YR",
    author_email="395622703@qq.com",
    description="聚类库",
    long_description_content_type="text/markdown",
    url="https://github.com/",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)